# Erk User Documentation

Documentation for end users of the erk tool.

## Contents

- [Project Setup](project-setup.md) - Configure erk for your repository (for maintainers)
- [Developer Onboarding](developer-onboarding.md) - Join a repo that has erk configured
- [Planner Setup](planner-setup.md) - Set up planner commands
- [Queue Setup](queue-setup.md) - Configure queue for remote execution
- [Facts](facts.md) - Scratchpad for quick reference facts

## Getting Started

- **Setting up erk for the first time?** See [Project Setup](project-setup.md)
- **Joining a repo that already has erk?** See [Developer Onboarding](developer-onboarding.md)
